==> cms-db_v0.7.9.tar.gz: admin/firstrun3.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('firstrun');
include('locale.inc.php');
$locale = new LocalizingClass('firstrun');

if (isset($_POST['user']) && isset($_POST['pass'])) {
	if ($_POST['pass'] == $_POST['repeat']) {
		$pass = sha1('root.php'.$_POST['pass']);
		$writethis = '<?php
		$user = "'.$_POST['user'].'";
		$pass = "'.$pass.'";
		?>';
		$datei = fopen('../data/users/root.php','w+');
		fwrite($datei,$writethis);
		fclose($datei);
		header('Location: firstrun4.php');
	} else {
		include('error.inc.php');
		throw_error(locale('desc_error-invalid-data',true), 'firstrun3.php?'.SID);
	}
} else {
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title_step3') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1><?php locale('title_step3') ?></h1>
<h2><?php locale('title_user') ?></h2>
<p>
	<?php locale('desc_user') ?>
</p>
<p>
	<form action="firstrun3.php" method="post">
		<?php locale('label_username') ?>: <input type="text" name="user" value="admin" /><br />
		<?php locale('label_password') ?>: <input type="password" name="pass" value="" /><br />
		<?php locale('desc_repeat') ?> <input type="password" name="repeat" value="" /><br />
		<input type="hidden" name="<?php echo session_name(); ?>" value="<?php echo session_id(); ?>" />
		<input type="submit" name="button" value="<?php locale('link_next') ?>" />
	</form>
</p>

</body>
</html>
<?php
}
?>

==> cms-db_v0.8.1.tar.gz: admin/firstrun3.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('firstrun');
include('locale.inc.php');
$locale = new LocalizingClass('firstrun');

if (isset($_POST['user']) && isset($_POST['pass'])) {
	if ($_POST['pass'] == $_POST['repeat']) {
		$pass = sha1('root.php'.$_POST['pass']);
		$writethis = '<?php
		$user = "'.$_POST['user'].'";
		$pass = "'.$pass.'";
		?>';
		$datei = fopen('../data/users/root.php','w+');
		fwrite($datei,$writethis);
		fclose($datei);
		header('Location: firstrun4.php?'.SID.csrf_protection_get());
	} else {
		include('error.inc.php');
		throw_error(locale('desc_error-invalid-data',true), 'firstrun3.php?'.SID.csrf_protection_get_html_ret());
	}
} else {
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title_step3') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1><?php locale('title_step3') ?></h1>
<h2><?php locale('title_user') ?></h2>
<p>
	<?php locale('desc_user') ?>
</p>
<p>
	<form action="firstrun3.php?<?php echo SID; csrf_protection_get_html() ?>" method="post">
		<?php locale('label_username') ?>: <input type="text" name="user" value="admin" /><br />
		<?php locale('label_password') ?>: <input type="password" name="pass" value="" /><br />
		<?php locale('desc_repeat') ?> <input type="password" name="repeat" value="" /><br />
		<input type="submit" name="button" value="<?php locale('link_next') ?>" />
	</form>
</p>

</body>
</html>
<?php
}
?>
